# we need the libs in /lib(64) as /usr might not be mounted
%define _libdir /%{_lib}
%define _usrlibdir /usr/%{_lib}

%define extraver rc16

# from lib/version.h
%define major 1
%define libname %mklibname dmraid %{major}
%define devname %mklibname dmraid -d

Summary:	Device-mapper ATARAID tool
Name:		dmraid
Version:	1.0.0
Release:	0.%{extraver}.20
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		http://people.redhat.com/~heinzm
Source0:	http://people.redhat.com/~heinzm/sw/dmraid/src/%{name}-%{version}.%{extraver}.tar.bz2
Source1:	fedora-dmraid-activation
Source2:	dmraid-activation.service
# (bluca) since fedora/redhat rpm is the real upstream for dmraid
# patch numbers < 100 are reserved for patches synced from fedora/redhat
# patch numbers > 100 are for our distro specific patches
Patch0:		dmraid-1.0.0.rc16-test_devices.patch
Patch1:		ddf1_lsi_persistent_name.patch
Patch2:		pdc_raid10_failure.patch
Patch3:		return_error_wo_disks.patch
Patch4:		fix_sil_jbod.patch
Patch5:		avoid_register.patch
#we dont use this# Patch6: move_pattern_file_to_var.patch
Patch7:		libversion.patch
Patch8:		libversion-display.patch
Patch9:		bz635995-data_corruption_during_activation_volume_marked_for_rebuild.patch
# Patch10: bz626417_8-faulty_message_after_unsuccessful_vol_registration.patch
Patch11:	bz626417_19-enabling_registration_degraded_volume.patch
Patch12:	bz626417_20-cleanup_some_compilation_warning.patch
Patch13:	bz626417_21-add_option_that_postpones_any_metadata_updates.patch
Patch101:	lib-events-libdmraid-events-isw-strfmt.patch
Patch102:	fix-linking.patch
Patch103:	libdmraid-events-soname.patch
Patch104:	libdmraid-events-install.patch

BuildRequires:	device-mapper-devel >= 1.02.02
BuildRequires:	device-mapper-event-devel >= 1.02.02
Requires:	%{libname} = %{EVRD}
Requires:	dmraid-events = %{EVRD}
Requires:	kpartx >= 0.4.8-16
Requires:	systemd
Requires(post):	systemd >= 195-4

%description
dmraid (Device-Mapper Raid tool) supports RAID device discovery, RAID
set activation, creation, removal, rebuild and display of properties for
ATARAID/DDF1 metadata.

dmraid uses libdevmapper and the device-mapper kernel runtime to create
devices with respective mappings for the ATARAID sets discovered.

The following ATARAID types are supported:

Adaptec HostRAID ASR
Highpoint HPT37X
Highpoint HPT45X
Intel Software RAID
JMicron JMB36x
LSI Logic MegaRAID
NVidia NForce
Promise FastTrack
Silicon Image Medley
SNIA DDF1
VIA Software RAID

%files
%defattr(-,root,root,755)
%doc CHANGELOG CREDITS KNOWN_BUGS README TODO doc/dmraid_design.txt
/sbin/dmraid
%{_mandir}/man8/dmraid.8*
%{_systemdrootdir}/fedora-dmraid-activation
%{_systemunitdir}/dmraid-activation.service
%ghost %dir /var/lock/dmraid

%post
%systemd_post dmraid-activation.service

#----------------------------------------------------------------------------

%package -n %{libname}
Summary:	Libraries for dmraid
Group:		System/Libraries

%description -n %{libname}
Provides libraries for dmraid.

%files -n %{libname}
%attr (0555,root,root) %{_libdir}/libdmraid.so.%{major}*

#----------------------------------------------------------------------------

%package -n %{devname}
Summary:	Development libraries and headers for dmraid
Group:		Development/Other
Provides:	%{name}-devel = %{version}.%{extraver}
Requires:	%{libname} = %{EVRD}

%description -n %{devname}
Provides a library interface for RAID device discovery, RAID set
activation and display of properties for ATARAID volumes.

%files -n %{devname}
%defattr(644,root,root,755)
%dir %{_includedir}/dmraid
%{_includedir}/dmraid/*.h
%{_libdir}/libdmraid.so

#----------------------------------------------------------------------------

%package events
Summary:	Dmraid event tool
Group:		System/Base
Requires:	%{name} = %{EVRD}
Requires:	device-mapper-event  >= 1.02.02

%description events
Provides a dmeventd DSO and the dmevent_tool to register devices with it
for device monitoring. All active RAID sets should be manually registered
with dmevent_tool.

%files events
%defattr(-,root,root,755)
/sbin/dmevent_tool
%attr (0555,root,root) %{_libdir}/libdmraid-events-isw.so
%{_mandir}/man8/dmevent_tool*

#----------------------------------------------------------------------------

%prep
%setup -qn %{name}/%{version}.%{extraver}
%patch0 -p1 -b .test_devices
%patch1 -p1 -b .ddf1_lsi_persistent_name
%patch2 -p1 -b .pdc_raid10_failure
%patch3 -p1 -b .return_error_wo_disks
%patch4 -p1 -b .fix_sil_jbod
%patch5 -p1 -b .avoid_register
%patch7 -p1 -b .libversion
%patch8 -p1 -b .libversion_display
%patch9 -p1 -b .bz635995
%patch11 -p1 -b .bz626417_19
%patch12 -p1 -b .bz626417_20
%patch13 -p1 -b .bz626417_21

%patch101 -p1 -b .libdmraid_events_isw_strfmt
%patch102 -p1 -b .linking
%patch103 -p1 -b .lib_events_soname
%patch104 -p1 -b .lib_events_install

%build
%configure2_5x \
	--with-user=`id -un` \
	--with-group=`id -gn` \
	--disable-libselinux \
	--disable-libsepol \
	--enable-led \
	--enable-intel_led \
	--enable-shared_lib
make

%install
%makeinstall -s sbindir=%{buildroot}/sbin
rm -f %{buildroot}%{_libdir}/libdmraid.a

mkdir -p %{buildroot}/var/lock/dmraid

# Install systemd unit
install -d %{buildroot}%{_systemdrootdir}
install -d %{buildroot}%{_systemunitdir}
install -m 755 %{SOURCE1} %{buildroot}%{_systemdrootdir}/fedora-dmraid-activation
install -m 444 %{SOURCE2} %{buildroot}%{_systemunitdir}/dmraid-activation.service

chmod 755 %{buildroot}%{_libdir}/libdmraid-events-isw.so
chmod 755 %{buildroot}%{_libdir}/libdmraid.so.%{major}*


%changelog

* Sat Jan 02 2016 Andrey Bondrov <andrey.bondrov@rosalab.ru> 1.0.0-0.rc16.20
- (09d040a) Install fedora-dmraid-activation to a proper location


